require 'json'
require 'uu/os/gvc/button'
require 'uu/os/gvc/menu_model'

module UU
  module OS
    module GVC

      # Drop-down button component.
      class DropDownButton < UU::OS::GVC::Button

        # Represents the menu of the dropdown button. It's possible to add, insert
        # or remove items from the model.
        #
        # @example
        #   # get current menu
        #   data = dd_button.data # MenuModel object
        #
        #   # get number of items
        #   data.number_of_rows # 5
        #
        #   # remove third item
        #   data.remove_item(2)
        #
        #   # add a separator and then another item
        #   data.add_item({})
        #   data.add_item({ :text => "Another item", :actionUri => "ues:TER:ART:?UC123456" })
        #
        #   # set MenuModel with single item
        #   dd_button.data = UU::OS::GVC::MenuModel.new([
        #     { :text => "The only choice", :actionUri => "http://google.com/", :disabled => false, :target => "NEW_WINDOW" }
        #   ])
        #
        # @param [UU::OS::GVC::MenuModel] MenuModel object.
        # @return [UU::OS::GVC::MenuModel] MenuModel object.
        attr_accessor :data

        # The URI to get the menu model data from. The component does not automatically
        # load this URI. If it's required to access / modify MenuModel stored in this URI,
        # it must be done by the developer that uses this component.
        attr_reader :data_uri

        # Creates new instance of DropDownButton component.
        #
        # @param [UU::OS::GVC::Container] container Container where to insert new component.
        # @param [String, Hash, Component] data Initialization data (optional).
        def initialize(container, data = nil)
          super(container, data)
          json_data = attributes[:data]
          if !json_data.kind_of? MenuModel
            attributes[:data] = MenuModel.new(json_data)
          end
        end

        def data_uri
          attributes[:dataUri]
        end

        def data
          attributes[:data]
        end

        def data=(data)
          if data.kind_of? MenuModel
            attributes[:data] = data
          else
            raise ArgumentError.new("DropDownButton data must be MenuModel, but was #{data.class}.")
          end
        end
      end
    end
  end
end
