require 'uu/os/gvc/component'

module UU
  module OS
    module GVC

      # Image component.
      class Image < UU::OS::GVC::Component

        # Image width.
        attr_reader :width

        # Image height.
        attr_reader :height

        # The data for the image. The data is a Hash and can contain:
        # * imageUri [String, UESURI] - the URI of the image
        # * imageAreas [Array] - list of active (clickable) areas of the image. Each item is a Hash
        #                        and can contain:
        # ** shapeData [String] - the shape of the clickable area. If the shape is
        #                         not given, the whole image will be clickable. *NOT YET SUPPORTED* - shapeData
        #                         is currently always treated as if it was not given so it makes
        #                         sense to specify at most 1 item in the imageAreas list.
        # ** actionUri [String, UESURI] - URI to navigate to when this area is clicked.
        # ** target [String] - the target window where the action URI will be opened - one of "CURRENT_WINDOW" (default),
        #          "NEW_WINDOW", "DIALOG_WINDOW". For backward compatibility it's also possible to use older equivalents
        #          "SELF", "NEW" and "MODAL".
        # ** tooltip [String] - the tooltip to display when hovering this area.
        #
        # @example
        #   # clickable image with tooltip
        #   image = view.get_components_by_code('image')[0]
        #   image.data = {
        #     :imageUri => 'ues:TER:ART:AP_IMAGE1',
        #     :imageAreas => [
        #       {
        #         :actionUri => 'ues:TER:ART:GALLERY',
        #         :target => 'NEW',
        #         :tooltip => 'Go to gallery'
        #       }
        #     ]
        #   }
        attr_accessor :data

        # The URI of the property to get the data from (see {#data}).
        # Note that due to backward compatibility, it's also possible to set
        # URI of the actual image (equivalent of data[:imageUri]). The URI in
        # {#data} takes precedence though.
        attr_accessor :data_uri

        def data
          attributes[:data]
        end

        def data=(data)
          attributes[:data] = data
        end

        def data_uri
          attributes[:dataUri]
        end

        def data_uri=(data_uri)
          attributes[:dataUri] = data_uri
        end

        def height
          attributes[:height]
        end

        def width
          attributes[:width]
        end

      end

    end
  end
end
