require 'uu/os/gvc/component'

module UU
  module OS
    module GVC

      # Tree component.
      class Tree < UU::OS::GVC::Component
        # Tree data binding. Data may contain hash describing tree node, in format.
        # 
        # {
        #    "opened" : true,
        #    "component" : {
        #      ...
        #    },
        #    "children" : [ ... ]
        # }
        #
        # Attribute children may contains list of children nodes defined by same hash format.
        # Whole tree is composed by nodes and its list of children nodes.
        #
        # Attribute component may contain only text or whole component definition:
        #
        # "component" : {
        #   "text" : "Node 1"
        # }
        #
        # or for component ( in this case you can add any attribute of defined component )
        #
        # "component" : {
        #   "componentType" : "uu.os.gvc.link",
        #   "text" : "Node 1",
        #   "tooltip" : "Node 1 Tooltip",
        #   ...
        # }
        attr_accessor :data
        
        # Tree dataUri. Set UESURI must link to artifact property of type short text, text or BLOB and linked property must contain 
        # similar json structure like in data attribute example. 
        attr_accessor :data_uri
                
        def data
          attributes[:data]
        end
        
        def data=(data)
          attributes[:data] = data
        end
        
        def data_uri
          attributes[:dataUri]
        end
                
        def data_uri=(data_uri)
          attributes[:dataUri] = data_uri
        end
                
      end
    end
  end
end
